=======
Credits
=======

Development Lead
----------------

* Szczepan Cieślik <szczepan.cieslik@gmail.com>

Contributors
------------

(In alphabetical order)

* Avraham Shukron <avraham.shukron@gmail.com>
* Chris Targett <chris.targett@xlevus.net>
* Daniel Schiavini <d.schiavini@ultimaker.com>
* Dima Kuznetsov <dima.kuznetsov@toganetworks.com>
* Hugo van Kemenade <hugovk@users.noreply.github.com>
* Jannis Leidel <jannis@leidel.info>
* Johannes Garimort <johannes.garimort@gmx.net>
* Omer Anson <omer.anson@toganetworks.com>
* Pavel Lipchak <kazemat92@gmail.com>
* Roberto Fernandez Diaz <robertofd1995@users.noreply.github.com>
* Vorren
